@@ -36,7 +36,7 @@
 
 namespace xs { namespace date {
 
-Date* SV2C_DATE_FUNC (SV* arg, const tz* zone, Date* operand) {
+Date* SV2C_DATE_FUNC (pTHX_ SV* arg, const tz* zone, Date* operand) {
     ptime_t epoch = 0;
     
     if (SvOK(arg)) {
@@ -74,7 +74,7 @@ Date* SV2C_DATE_FUNC (SV* arg, const tz* zone, Date* operand) {
                     
                     if (zone == NULL) {
                         ref = hv_fetch(hash, "tz", 2, 0);
-                        if (ref != NULL) zone = tzget_required(*ref);
+                        if (ref != NULL) zone = tzget_required(aTHX_ *ref);
                     }
                 }
                 else if (SvTYPE(rarg) == SVt_PVAV) {
@@ -115,7 +115,7 @@ Date* SV2C_DATE_FUNC (SV* arg, const tz* zone, Date* operand) {
 
 #ifdef SV2C_DATEREL_FUNC
 
-DateRel* SV2C_DATEREL_FUNC (SV* arg, DateRel* operand) {
+DateRel* SV2C_DATEREL_FUNC (pTHX_ SV* arg, DateRel* operand) {
     if (!SvOK(arg)) {
         SV2C_DATEREL_ACTION(0,0,0,0,0,0);
         return operand;
@@ -174,11 +174,11 @@ DateRel* SV2C_DATEREL_FUNC (SV* arg, DateRel* operand) {
     }
 }
 
-DateRel* SV2C_DATEREL_FUNC (SV* fromSV, SV* tillSV, DateRel* operand) {
+DateRel* SV2C_DATEREL_FUNC (pTHX_ SV* fromSV, SV* tillSV, DateRel* operand) {
     Date from((ptime_t) 0);
     Date till((ptime_t) 0);
-    date_set(fromSV, NULL, &from);
-    date_set(tillSV, NULL, &till);
+    date_set(aTHX_ fromSV, NULL, &from);
+    date_set(aTHX_ tillSV, NULL, &till);
     SV2C_DATEREL_ACTION(from.date(), till.date());
     return operand;
 }
@@ -187,14 +187,14 @@ DateRel* SV2C_DATEREL_FUNC (SV* fromSV, SV* tillSV, DateRel* operand) {
 
 #ifdef SV2C_DATEINT_FUNC
 
-DateInt* SV2C_DATEINT_FUNC (SV* arg, DateInt* operand) {
+DateInt* SV2C_DATEINT_FUNC (pTHX_ SV* arg, DateInt* operand) {
     if (SvOK(arg) && SvROK(arg)) {
         SV* argval = SvRV(arg);
         if (SvTYPE(argval) == SVt_PVAV) {
             AV* arr = (AV*) argval;
             SV** elemref1 = av_fetch(arr, 0, 0);
             SV** elemref2 = av_fetch(arr, 1, 0);
-            if (elemref1 != NULL && elemref2 != NULL) return SV2C_DATEINT_FUNC(*elemref1, *elemref2, operand);
+            if (elemref1 != NULL && elemref2 != NULL) return SV2C_DATEINT_FUNC(aTHX_ *elemref1, *elemref2, operand);
         }
     }
     else if (SvPOK(arg)) {
@@ -207,11 +207,11 @@ DateInt* SV2C_DATEINT_FUNC (SV* arg, DateInt* operand) {
     SV2C_TYPE_CROAK;
 }
 
-DateInt* SV2C_DATEINT_FUNC (SV* fromSV, SV* tillSV, DateInt* operand) {
+DateInt* SV2C_DATEINT_FUNC (pTHX_ SV* fromSV, SV* tillSV, DateInt* operand) {
     Date from((ptime_t) 0);
     Date till((ptime_t) 0);
-    date_set(fromSV, NULL, &from);
-    date_set(tillSV, NULL, &till);
+    date_set(aTHX_ fromSV, NULL, &from);
+    date_set(aTHX_ tillSV, NULL, &till);
     SV2C_DATEINT_ACTION(&from, &till);
     return operand;
 }
